==============
Altair Express
==============


.. image:: https://img.shields.io/pypi/v/altair_express.svg
        :target: https://pypi.python.org/pypi/altair_express

.. image:: https://img.shields.io/travis/dwootton/altair_express.svg
        :target: https://travis-ci.com/dwootton/altair_express

.. image:: https://readthedocs.org/projects/altair-express/badge/?version=latest
        :target: https://altair-express.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Create interactive data visualizations in one line of code.


* Free software: MIT license
* Documentation: https://altair-express.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
